# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tidypolars']

package_data = \
{'': ['*']}

install_requires = \
['polars>=0.13.0']

setup_kwargs = {
    'name': 'tidypolars',
    'version': '0.2.11',
    'description': 'Tidy interface to polars',
    'long_description': '# tidypolars\n[![PyPI Latest Release](https://img.shields.io/pypi/v/tidypolars.svg)](https://pypi.org/project/tidypolars/)\n\ntidypolars is a data frame library built on top of the blazingly fast [polars](https://github.com/pola-rs/polars) library that gives access to methods and functions familiar to R tidyverse users.\n\n## Installation\n```bash\n$ pip3 install tidypolars\n```\n\n### General syntax\n\ntidypolars methods are designed to work like tidyverse functions:\n\n```python\nimport tidypolars as tp\nfrom tidypolars import col, desc\n\ndf = tp.Tibble(x = range(3), y = range(3, 6), z = [\'a\', \'a\', \'b\'])\n\n(\n    df\n    .select(\'x\', \'y\', \'z\')\n    .filter(col(\'x\') < 4, col(\'y\') > 1)\n    .arrange(desc(\'z\'), \'x\')\n    .mutate(double_x = col(\'x\') * 2,\n            x_plus_y = col(\'x\') + col(\'y\'))\n)\n┌─────┬─────┬─────┬──────────┬──────────┐\n│ x   ┆ y   ┆ z   ┆ double_x ┆ x_plus_y │\n│ --- ┆ --- ┆ --- ┆ ---      ┆ ---      │\n│ i64 ┆ i64 ┆ str ┆ i64      ┆ i64      │\n╞═════╪═════╪═════╪══════════╪══════════╡\n│ 2   ┆ 5   ┆ b   ┆ 4        ┆ 7        │\n├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ 0   ┆ 3   ┆ a   ┆ 0        ┆ 3        │\n├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ 1   ┆ 4   ┆ a   ┆ 2        ┆ 5        │\n└─────┴─────┴─────┴──────────┴──────────┘\n```\n\nThe key difference from R is that column names must be wrapped in `col()` in the following methods:\n* `.filter()`\n* `.mutate()`\n* `.summarize()`\n\nThe general idea - when doing calculations on a column you need to wrap it in `col()`. When doing simple column selections (like in `.select()`) you can pass the column names as strings.\n\nA full list of functions can be found [here](https://tidypolars.readthedocs.io/en/latest/reference.html).\n\n### Group by syntax\n\nMethods operate by group by calling the `by` arg.\n\n* A single column can be passed with `by = \'z\'`\n* Multiple columns can be passed with `by = [\'y\', \'z\']`\n\n```python\n(\n    df\n    .summarize(avg_x = tp.mean(col(\'x\')),\n               by = \'z\')\n)\n┌─────┬───────┐\n│ z   ┆ avg_x │\n│ --- ┆ ---   │\n│ str ┆ f64   │\n╞═════╪═══════╡\n│ a   ┆ 0.5   │\n├╌╌╌╌╌┼╌╌╌╌╌╌╌┤\n│ b   ┆ 2     │\n└─────┴───────┘\n```\n\n### Selecting/dropping columns\n\ntidyselect functions can be mixed with normal selection when selecting columns:\n\n```python\ndf = tp.Tibble(x1 = range(3), x2 = range(3), y = range(3), z = range(3))\n\ndf.select(tp.starts_with(\'x\'), \'z\')\n┌─────┬─────┬─────┐\n│ x1  ┆ x2  ┆ z   │\n│ --- ┆ --- ┆ --- │\n│ i64 ┆ i64 ┆ i64 │\n╞═════╪═════╪═════╡\n│ 0   ┆ 0   ┆ 0   │\n├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n│ 1   ┆ 1   ┆ 1   │\n├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n│ 2   ┆ 2   ┆ 2   │\n└─────┴─────┴─────┘\n```\n\nTo drop columns use the `.drop()` method:\n\n```python\ndf.drop(tp.starts_with(\'x\'), \'z\')\n┌─────┐\n│ y   │\n│ --- │\n│ i64 │\n╞═════╡\n│ 0   │\n├╌╌╌╌╌┤\n│ 1   │\n├╌╌╌╌╌┤\n│ 2   │\n└─────┘\n```\n\n### Converting to/from pandas data frames\n\nIf you need to use a package that requires pandas data frames, you can convert from a tidypolars `Tibble` to\na pandas `DataFrame`.\n\nTo do this you\'ll first need to install pyarrow:\n\n```bash\npip3 install pyarrow\n```\n\nTo convert to a pandas `DataFrame`:\n\n```python\ndf = df.to_pandas()\n```\n\nTo convert from a pandas `DataFrame` to a tidypolars `Tibble`:\n\n```python\ndf = tp.from_pandas(df)\n```\n\n## Speed Comparisons\n\nA few notes:\n\n* Comparing times from separate functions typically isn\'t very useful. For example - the `.summarize()` tests\n  were performed on a different dataset from `.pivot_wider()`.\n* All tests are run 5 times. The times shown are the median of those 5 runs.\n* All timings are in milliseconds.\n* All tests can be found in the source code \n  [here](https://github.com/markfairbanks/tidypolars/blob/main/benchmarks/benchmarks.ipynb).\n* FAQ - Why are some `tidypolars` functions faster than their `polars` counterpart?\n  + Short answer - they\'re not! After all they\'re just using `polars` in the background.\n  + Long answer - All python functions have some slight natural variation in their execution time. \n  By chance the `tidypolars` runs were slightly shorter on those specific functions on this\n  iteration of the tests. However one goal of these tests is to show that the "time cost" of\n  translating syntax to `polars` is very negligible to the\n  user (especially on medium-to-large datasets).\n* Lastly I\'d like to mention that these tests were not rigorously created to cover all angles equally. They are just meant to be used as general insight into the performance of these packages.\n\n```python\n┌─────────────┬────────────┬─────────┬──────────┐\n│ func_tested ┆ tidypolars ┆ polars  ┆ pandas   │\n│ ---         ┆ ---        ┆ ---     ┆ ---      │\n│ str         ┆ f64        ┆ f64     ┆ f64      │\n╞═════════════╪════════════╪═════════╪══════════╡\n│ arrange     ┆ 215.971    ┆ 214.409 ┆ 595.035  │\n├╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ case_when   ┆ 111.781    ┆ 98.791  ┆ 130.052  │\n├╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ distinct    ┆ 61.887     ┆ 55.852  ┆ 399.186  │\n├╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ filter      ┆ 34.21      ┆ 32.909  ┆ 264.426  │\n├╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ left_join   ┆ 150.432    ┆ 159.879 ┆ 1479.041 │\n├╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ mutate      ┆ 9.111      ┆ 9.317   ┆ 142.83   │\n├╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ pivot_wider ┆ 50.609     ┆ 39.22   ┆ 107.185  │\n├╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤\n│ summarize   ┆ 81.473     ┆ 82.283  ┆ 566.598  │\n└─────────────┴────────────┴─────────┴──────────┘\n```\n\n## Contributing\n\nInterested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.\n',
    'author': 'Mark Fairbanks',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<3.11',
}


setup(**setup_kwargs)
